@@ -3,6 +3,7 @@ package controllers
 import (
 	"errors"
 	"fmt"
+	"strings"
 
 	"github.com/jesseduffield/lazygit/pkg/commands/git_commands"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
@@ -121,52 +122,93 @@ func (self *BasicCommitsController) GetKeybindings(opts types.KeybindingsOpts) [
 	return bindings
 }
 
+func (self *BasicCommitsController) getCommitMessageBody(hash string) string {
+	commitMessageBody, err := self.c.Git().Commit.GetCommitMessage(hash)
+	if err != nil {
+		return ""
+	}
+	_, body := self.c.Helpers().Commits.SplitCommitMessageAndDescription(commitMessageBody)
+	return body
+}
+
 func (self *BasicCommitsController) copyCommitAttribute(commit *models.Commit) error {
-	return self.c.Menu(types.CreateMenuOptions{
-		Title: self.c.Tr.Actions.CopyCommitAttributeToClipboard,
-		Items: []*types.MenuItem{
-			{
-				Label: self.c.Tr.CommitHash,
-				OnPress: func() error {
-					return self.copyCommitHashToClipboard(commit)
-				},
-			},
-			{
-				Label: self.c.Tr.CommitSubject,
-				OnPress: func() error {
-					return self.copyCommitSubjectToClipboard(commit)
-				},
-				Key: 's',
-			},
-			{
-				Label: self.c.Tr.CommitMessage,
-				OnPress: func() error {
-					return self.copyCommitMessageToClipboard(commit)
-				},
-				Key: 'm',
-			},
-			{
-				Label: self.c.Tr.CommitURL,
-				OnPress: func() error {
-					return self.copyCommitURLToClipboard(commit)
-				},
-				Key: 'u',
-			},
-			{
-				Label: self.c.Tr.CommitDiff,
-				OnPress: func() error {
-					return self.copyCommitDiffToClipboard(commit)
-				},
-				Key: 'd',
-			},
-			{
-				Label: self.c.Tr.CommitAuthor,
-				OnPress: func() error {
-					return self.copyAuthorToClipboard(commit)
-				},
-				Key: 'a',
+	commitMessageBody := self.getCommitMessageBody(commit.Hash)
+	var commitMessageBodyDisabled *types.DisabledReason
+	if commitMessageBody == "" {
+		commitMessageBodyDisabled = &types.DisabledReason{
+			Text: self.c.Tr.CommitHasNoMessageBody,
+		}
+	}
+
+	items := []*types.MenuItem{
+		{
+			Label: self.c.Tr.CommitHash,
+			OnPress: func() error {
+				return self.copyCommitHashToClipboard(commit)
 			},
 		},
+		{
+			Label: self.c.Tr.CommitSubject,
+			OnPress: func() error {
+				return self.copyCommitSubjectToClipboard(commit)
+			},
+			Key: 's',
+		},
+		{
+			Label: self.c.Tr.CommitMessage,
+			OnPress: func() error {
+				return self.copyCommitMessageToClipboard(commit)
+			},
+			Key: 'm',
+		},
+		{
+			Label:          self.c.Tr.CommitMessageBody,
+			DisabledReason: commitMessageBodyDisabled,
+			OnPress: func() error {
+				return self.copyCommitMessageBodyToClipboard(commitMessageBody)
+			},
+			Key: 'b',
+		},
+		{
+			Label: self.c.Tr.CommitURL,
+			OnPress: func() error {
+				return self.copyCommitURLToClipboard(commit)
+			},
+			Key: 'u',
+		},
+		{
+			Label: self.c.Tr.CommitDiff,
+			OnPress: func() error {
+				return self.copyCommitDiffToClipboard(commit)
+			},
+			Key: 'd',
+		},
+		{
+			Label: self.c.Tr.CommitAuthor,
+			OnPress: func() error {
+				return self.copyAuthorToClipboard(commit)
+			},
+			Key: 'a',
+		},
+	}
+
+	commitTagsItem := types.MenuItem{
+		Label: self.c.Tr.CommitTags,
+		OnPress: func() error {
+			return self.copyCommitTagsToClipboard(commit)
+		},
+		Key: 't',
+	}
+
+	if len(commit.Tags) == 0 {
+		commitTagsItem.DisabledReason = &types.DisabledReason{Text: self.c.Tr.CommitHasNoTags}
+	}
+
+	items = append(items, &commitTagsItem)
+
+	return self.c.Menu(types.CreateMenuOptions{
+		Title: self.c.Tr.Actions.CopyCommitAttributeToClipboard,
+		Items: items,
 	})
 }
 
@@ -242,6 +284,16 @@ func (self *BasicCommitsController) copyCommitMessageToClipboard(commit *models.
 	return nil
 }
 
+func (self *BasicCommitsController) copyCommitMessageBodyToClipboard(commitMessageBody string) error {
+	self.c.LogAction(self.c.Tr.Actions.CopyCommitMessageBodyToClipboard)
+	if err := self.c.OS().CopyToClipboard(commitMessageBody); err != nil {
+		return err
+	}
+
+	self.c.Toast(self.c.Tr.CommitMessageBodyCopiedToClipboard)
+	return nil
+}
+
 func (self *BasicCommitsController) copyCommitSubjectToClipboard(commit *models.Commit) error {
 	message, err := self.c.Git().Commit.GetCommitSubject(commit.Hash)
 	if err != nil {
@@ -257,6 +309,18 @@ func (self *BasicCommitsController) copyCommitSubjectToClipboard(commit *models.
 	return nil
 }
 
+func (self *BasicCommitsController) copyCommitTagsToClipboard(commit *models.Commit) error {
+	message := strings.Join(commit.Tags, "\n")
+
+	self.c.LogAction(self.c.Tr.Actions.CopyCommitTagsToClipboard)
+	if err := self.c.OS().CopyToClipboard(message); err != nil {
+		return err
+	}
+
+	self.c.Toast(self.c.Tr.CommitTagsCopiedToClipboard)
+	return nil
+}
+
 func (self *BasicCommitsController) openInBrowser(commit *models.Commit) error {
 	url, err := self.c.Helpers().Host.GetCommitURL(commit.Hash)
 	if err != nil {
