@@ -67,10 +67,7 @@ func (self *SubCommitsHelper) ViewSubCommits(opts ViewSubCommitsOpts) error {
 	subCommitsContext.GetView().ClearSearch()
 	subCommitsContext.GetView().TitlePrefix = opts.Context.GetView().TitlePrefix
 
-	err = self.c.PostRefreshUpdate(self.c.Contexts().SubCommits)
-	if err != nil {
-		return err
-	}
+	self.c.PostRefreshUpdate(self.c.Contexts().SubCommits)
 
 	self.c.Context().Push(self.c.Contexts().SubCommits)
 	return nil
