@@ -111,7 +111,9 @@ func (self *StashController) handleStashApply(stashEntry *models.StashEntry) err
 		if err != nil {
 			return err
 		}
-		self.c.Context().Push(self.c.Contexts().Files)
+		if self.c.UserConfig().Gui.SwitchToFilesAfterStashApply {
+			self.c.Context().Push(self.c.Contexts().Files)
+		}
 		return nil
 	}
 
@@ -138,7 +140,9 @@ func (self *StashController) handleStashPop(stashEntry *models.StashEntry) error
 		if err != nil {
 			return err
 		}
-		self.c.Context().Push(self.c.Contexts().Files)
+		if self.c.UserConfig().Gui.SwitchToFilesAfterStashPop {
+			self.c.Context().Push(self.c.Contexts().Files)
+		}
 		return nil
 	}
 
@@ -197,13 +201,13 @@ func (self *StashController) handleRenameStashEntry(stashEntry *models.StashEntr
 		HandleConfirm: func(response string) error {
 			self.c.LogAction(self.c.Tr.Actions.RenameStash)
 			err := self.c.Git().Stash.Rename(stashEntry.Index, response)
-			_ = self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.STASH}})
 			if err != nil {
+				_ = self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.STASH}})
 				return err
 			}
 			self.context().SetSelection(0) // Select the renamed stash
 			self.context().FocusLine()
-			return nil
+			return self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.STASH}})
 		},
 	})
 
