@@ -19,11 +19,12 @@ func toStringSlice(str string) []string {
 
 func TestRenderFileTree(t *testing.T) {
 	scenarios := []struct {
-		name           string
-		root           *filetree.FileNode
-		files          []*models.File
-		collapsedPaths []string
-		expected       []string
+		name            string
+		root            *filetree.FileNode
+		files           []*models.File
+		collapsedPaths  []string
+		showLineChanges bool
+		expected        []string
 	}{
 		{
 			name:     "nil node",
@@ -37,6 +38,22 @@ func TestRenderFileTree(t *testing.T) {
 			},
 			expected: []string{" M test"},
 		},
+		{
+			name: "numstat",
+			files: []*models.File{
+				{Name: "test", ShortStatus: " M", HasStagedChanges: true, LinesAdded: 1, LinesDeleted: 1},
+				{Name: "test2", ShortStatus: " M", HasStagedChanges: true, LinesAdded: 1},
+				{Name: "test3", ShortStatus: " M", HasStagedChanges: true, LinesDeleted: 1},
+				{Name: "test4", ShortStatus: " M", HasStagedChanges: true, LinesAdded: 0, LinesDeleted: 0},
+			},
+			showLineChanges: true,
+			expected: []string{
+				" M test +1 -1",
+				" M test2 +1",
+				" M test3 -1",
+				" M test4",
+			},
+		},
 		{
 			name: "big example",
 			files: []*models.File{
@@ -72,7 +89,7 @@ M  file1
 			for _, path := range s.collapsedPaths {
 				viewModel.ToggleCollapsed(path)
 			}
-			result := RenderFileTree(viewModel, nil, false)
+			result := RenderFileTree(viewModel, nil, false, s.showLineChanges)
 			assert.EqualValues(t, s.expected, result)
 		})
 	}
